==> qmmp_0.2.3.orig.tar.gz: qmmp-0.2.3/src/plugins/General/notifier/translations/notifier_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="uk">
<defaultcodec></defaultcodec>
<context>
    <name>NotifierFactory</name>
    <message>
        <location filename="../notifierfactory.cpp" line="30"/>
        <source>Notifier Plugin</source>
        <translation>Модуль повідомлень</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="49"/>
        <source>About Notifier Plugin</source>
        <translation>Про модуль повідомлень</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="50"/>
        <source>Qmmp Notifier Plugin</source>
        <translation>Модуль повідомлень для Qmmp</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="51"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Розробник: Ілля Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>Notifier Plugin Settings</source>
        <translation>Налаштування модуля повідомлень</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="19"/>
        <source>Psi Notification</source>
        <translation>Повідомлення Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="25"/>
        <source>Enable Psi notification</source>
        <translation>Увімкнути повідомлення Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Desktop Notification</source>
        <translation>Повідомлення на робочому столі</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Enable desktop notification</source>
        <translation>Відображати повідомлення на робочому столі</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Message delay, ms:</source>
        <translation>Затримка повідомлення, мс:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="74"/>
        <source>Position</source>
        <translation>Позиція</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="248"/>
        <source>OK</source>
        <translation>Застосувати</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="255"/>
        <source>Cancel</source>
        <translation>Відміна</translation>
    </message>
</context>
</TS>

==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/General/notifier/translations/notifier_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk">
<context>
    <name>NotifierFactory</name>
    <message>
        <location filename="../notifierfactory.cpp" line="30"/>
        <source>Notifier Plugin</source>
        <translation>Модуль повідомлень</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="50"/>
        <source>About Notifier Plugin</source>
        <translation>Про модуль повідомлень</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="51"/>
        <source>Qmmp Notifier Plugin</source>
        <translation>Модуль повідомлень для Qmmp</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="52"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Розробник: Ілля Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>PopupWidget</name>
    <message>
        <location filename="../popupwidget.cpp" line="115"/>
        <source>Volume:</source>
        <translation>Гучність:</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>Notifier Plugin Settings</source>
        <translation>Налаштування модуля повідомлень</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="19"/>
        <source>Psi Notification</source>
        <translation>Повідомлення Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="25"/>
        <source>Enable Psi notification</source>
        <translation>Увімкнути повідомлення Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Desktop Notification</source>
        <translation>Повідомлення на робочому столі</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="248"/>
        <source>Position</source>
        <translation>Позиція</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Song change notification</source>
        <translation>Повідомлення зміни треку</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Volume change notification</source>
        <translation>Повідомлення зміни гучності</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Delay, ms:</source>
        <translation>Затримка, мс:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="81"/>
        <source>Transparency</source>
        <translation>Прозорість</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="104"/>
        <source>0</source>
        <translation></translation>
    </message>
</context>
</TS>
